/**
 ******************************************************************************
 * @file    ensi_uart.h
 * @author  D. Boudier (ENSICAEN)
 *
 * @brief   UART driver for STM32F4xx.
 *          Provides driver functions for UART communication through
 *          the USART2 peripheral (STLink Virtual COM Port).
 ******************************************************************************
 */

/* Define to prevent recursive inclusion ------------------------------------*/
#ifndef __ENSI_UART_H
#define __ENSI_UART_H


/* Includes -----------------------------------------------------------------*/
#define USE_NUCLEO_L0x3
//#define USE_NUCLEO_F411

#if defined(USE_NUCLEO_F411)
#include "stm32f4xx_hal.h"
#elif defined(USE_NUCLEO_L0x3)
#include "stm32l0xx_hal.h"
#endif

/* Exported constants -------------------------------------------------------*/
#define UART_BUFFERSIZE 	256


/* Exported functions -------------------------------------------------------*/

/**
 * @brief USART2 init function
 * @param none
 * @retval none
 */
void ENSI_UART_Init();


/**
 * @brief Sends 8-bit payload through UART by polling
 * @param txPayload: byte to be sent
 * @retval none
 */
void ENSI_UART_PutChar(const uint8_t txPayload);


/**
 * @brief Sends character string through UART by polling
 * @param *txPayload: pointer to the string to be sent
 * @retval none
 */
void ENSI_UART_PutString(const uint8_t *txString);


/**
 * @brief Waits for data to be stored in the circular buffer, then
  	  	  retrieves the received 8-bit payload (FIFO).
  	  	  The circular buffer is fed by the UART Rx ISR.
 * @param rxPayload: pointer to the payload to be retrieved
 * @retval non
 */
void ENSI_UART_GetChar(uint8_t *rxPayload);


/**
 * @brief Retrieves string from the Rx circular buffer.
 * @param *rxString: pointer to the string to be received
 */
void ENSI_UART_GetString(uint8_t *rxString);


#endif /* __ENSI_UART_H */
